@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -56,6 +56,7 @@ __protobuf__ = proto.module(
 
 class CreateTopicRequest(proto.Message):
     r"""Request for CreateTopic.
+
     Attributes:
         parent (str):
             Required. The parent location in which to create the topic.
@@ -71,45 +72,68 @@ class CreateTopicRequest(proto.Message):
             This value is structured like: ``my-topic-name``.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    topic = proto.Field(proto.MESSAGE, number=2, message=common.Topic,)
-    topic_id = proto.Field(proto.STRING, number=3,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    topic = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=common.Topic,
+    )
+    topic_id = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class GetTopicRequest(proto.Message):
     r"""Request for GetTopic.
+
     Attributes:
         name (str):
             Required. The name of the topic whose
             configuration to return.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class GetTopicPartitionsRequest(proto.Message):
     r"""Request for GetTopicPartitions.
+
     Attributes:
         name (str):
             Required. The topic whose partition
             information to return.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class TopicPartitions(proto.Message):
     r"""Response for GetTopicPartitions.
+
     Attributes:
         partition_count (int):
             The number of partitions in the topic.
     """
 
-    partition_count = proto.Field(proto.INT64, number=1,)
+    partition_count = proto.Field(
+        proto.INT64,
+        number=1,
+    )
 
 
 class ListTopicsRequest(proto.Message):
     r"""Request for ListTopics.
+
     Attributes:
         parent (str):
             Required. The parent whose topics are to be listed.
@@ -129,13 +153,23 @@ class ListTopicsRequest(proto.Message):
             token.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class ListTopicsResponse(proto.Message):
     r"""Response for ListTopics.
+
     Attributes:
         topics (Sequence[google.cloud.pubsublite_v1.types.Topic]):
             The list of topic in the requested parent.
@@ -150,12 +184,20 @@ class ListTopicsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    topics = proto.RepeatedField(proto.MESSAGE, number=1, message=common.Topic,)
-    next_page_token = proto.Field(proto.STRING, number=2,)
+    topics = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message=common.Topic,
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class UpdateTopicRequest(proto.Message):
     r"""Request for UpdateTopic.
+
     Attributes:
         topic (google.cloud.pubsublite_v1.types.Topic):
             Required. The topic to update. Its ``name`` field must be
@@ -165,24 +207,35 @@ class UpdateTopicRequest(proto.Message):
             to change.
     """
 
-    topic = proto.Field(proto.MESSAGE, number=1, message=common.Topic,)
+    topic = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=common.Topic,
+    )
     update_mask = proto.Field(
-        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+        proto.MESSAGE,
+        number=2,
+        message=field_mask_pb2.FieldMask,
     )
 
 
 class DeleteTopicRequest(proto.Message):
     r"""Request for DeleteTopic.
+
     Attributes:
         name (str):
             Required. The name of the topic to delete.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ListTopicSubscriptionsRequest(proto.Message):
     r"""Request for ListTopicSubscriptions.
+
     Attributes:
         name (str):
             Required. The name of the topic whose
@@ -202,13 +255,23 @@ class ListTopicSubscriptionsRequest(proto.Message):
             the page token.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class ListTopicSubscriptionsResponse(proto.Message):
     r"""Response for ListTopicSubscriptions.
+
     Attributes:
         subscriptions (Sequence[str]):
             The names of subscriptions attached to the
@@ -224,12 +287,19 @@ class ListTopicSubscriptionsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    subscriptions = proto.RepeatedField(proto.STRING, number=1,)
-    next_page_token = proto.Field(proto.STRING, number=2,)
+    subscriptions = proto.RepeatedField(
+        proto.STRING,
+        number=1,
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class CreateSubscriptionRequest(proto.Message):
     r"""Request for CreateSubscription.
+
     Attributes:
         parent (str):
             Required. The parent location in which to create the
@@ -251,25 +321,43 @@ class CreateSubscriptionRequest(proto.Message):
             subscription. Defaults to false.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    subscription = proto.Field(proto.MESSAGE, number=2, message=common.Subscription,)
-    subscription_id = proto.Field(proto.STRING, number=3,)
-    skip_backlog = proto.Field(proto.BOOL, number=4,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    subscription = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=common.Subscription,
+    )
+    subscription_id = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    skip_backlog = proto.Field(
+        proto.BOOL,
+        number=4,
+    )
 
 
 class GetSubscriptionRequest(proto.Message):
     r"""Request for GetSubscription.
+
     Attributes:
         name (str):
             Required. The name of the subscription whose
             configuration to return.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ListSubscriptionsRequest(proto.Message):
     r"""Request for ListSubscriptions.
+
     Attributes:
         parent (str):
             Required. The parent whose subscriptions are to be listed.
@@ -289,13 +377,23 @@ class ListSubscriptionsRequest(proto.Message):
             page token.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class ListSubscriptionsResponse(proto.Message):
     r"""Response for ListSubscriptions.
+
     Attributes:
         subscriptions (Sequence[google.cloud.pubsublite_v1.types.Subscription]):
             The list of subscriptions in the requested
@@ -312,13 +410,19 @@ class ListSubscriptionsResponse(proto.Message):
         return self
 
     subscriptions = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=common.Subscription,
+        proto.MESSAGE,
+        number=1,
+        message=common.Subscription,
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class UpdateSubscriptionRequest(proto.Message):
     r"""Request for UpdateSubscription.
+
     Attributes:
         subscription (google.cloud.pubsublite_v1.types.Subscription):
             Required. The subscription to update. Its ``name`` field
@@ -328,25 +432,43 @@ class UpdateSubscriptionRequest(proto.Message):
             fields to change.
     """
 
-    subscription = proto.Field(proto.MESSAGE, number=1, message=common.Subscription,)
+    subscription = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=common.Subscription,
+    )
     update_mask = proto.Field(
-        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+        proto.MESSAGE,
+        number=2,
+        message=field_mask_pb2.FieldMask,
     )
 
 
 class DeleteSubscriptionRequest(proto.Message):
     r"""Request for DeleteSubscription.
+
     Attributes:
         name (str):
             Required. The name of the subscription to
             delete.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class SeekSubscriptionRequest(proto.Message):
     r"""Request for SeekSubscription.
+
+    This message has `oneof`_ fields (mutually exclusive fields).
+    For each oneof, at most one member field can be set at the same time.
+    Setting any member of the oneof automatically clears all other
+    members.
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         name (str):
             Required. The name of the subscription to
@@ -354,12 +476,16 @@ class SeekSubscriptionRequest(proto.Message):
         named_target (google.cloud.pubsublite_v1.types.SeekSubscriptionRequest.NamedTarget):
             Seek to a named position with respect to the
             message backlog.
+
+            This field is a member of `oneof`_ ``target``.
         time_target (google.cloud.pubsublite_v1.types.TimeTarget):
             Seek to the first message whose publish or
             event time is greater than or equal to the
             specified query time. If no such message can be
             located, will seek to the end of the message
             backlog.
+
+            This field is a member of `oneof`_ ``target``.
     """
 
     class NamedTarget(proto.Enum):
@@ -368,19 +494,31 @@ class SeekSubscriptionRequest(proto.Message):
         TAIL = 1
         HEAD = 2
 
-    name = proto.Field(proto.STRING, number=1,)
-    named_target = proto.Field(proto.ENUM, number=2, oneof="target", enum=NamedTarget,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    named_target = proto.Field(
+        proto.ENUM,
+        number=2,
+        oneof="target",
+        enum=NamedTarget,
+    )
     time_target = proto.Field(
-        proto.MESSAGE, number=3, oneof="target", message=common.TimeTarget,
+        proto.MESSAGE,
+        number=3,
+        oneof="target",
+        message=common.TimeTarget,
     )
 
 
 class SeekSubscriptionResponse(proto.Message):
-    r"""Response for SeekSubscription long running operation.    """
+    r"""Response for SeekSubscription long running operation."""
 
 
 class OperationMetadata(proto.Message):
     r"""Metadata for long running operations.
+
     Attributes:
         create_time (google.protobuf.timestamp_pb2.Timestamp):
             The time the operation was created.
@@ -396,14 +534,29 @@ class OperationMetadata(proto.Message):
             Name of the verb executed by the operation.
     """
 
-    create_time = proto.Field(proto.MESSAGE, number=1, message=timestamp_pb2.Timestamp,)
-    end_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
-    target = proto.Field(proto.STRING, number=3,)
-    verb = proto.Field(proto.STRING, number=4,)
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=timestamp_pb2.Timestamp,
+    )
+    end_time = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
+    target = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    verb = proto.Field(
+        proto.STRING,
+        number=4,
+    )
 
 
 class CreateReservationRequest(proto.Message):
     r"""Request for CreateReservation.
+
     Attributes:
         parent (str):
             Required. The parent location in which to create the
@@ -419,13 +572,24 @@ class CreateReservationRequest(proto.Message):
             This value is structured like: ``my-reservation-name``.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    reservation = proto.Field(proto.MESSAGE, number=2, message=common.Reservation,)
-    reservation_id = proto.Field(proto.STRING, number=3,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    reservation = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=common.Reservation,
+    )
+    reservation_id = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class GetReservationRequest(proto.Message):
     r"""Request for GetReservation.
+
     Attributes:
         name (str):
             Required. The name of the reservation whose configuration to
@@ -433,11 +597,15 @@ class GetReservationRequest(proto.Message):
             projects/{project_number}/locations/{location}/reservations/{reservation_id}
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ListReservationsRequest(proto.Message):
     r"""Request for ListReservations.
+
     Attributes:
         parent (str):
             Required. The parent whose reservations are to be listed.
@@ -457,13 +625,23 @@ class ListReservationsRequest(proto.Message):
             page token.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class ListReservationsResponse(proto.Message):
     r"""Response for ListReservations.
+
     Attributes:
         reservations (Sequence[google.cloud.pubsublite_v1.types.Reservation]):
             The list of reservation in the requested
@@ -480,13 +658,19 @@ class ListReservationsResponse(proto.Message):
         return self
 
     reservations = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=common.Reservation,
+        proto.MESSAGE,
+        number=1,
+        message=common.Reservation,
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class UpdateReservationRequest(proto.Message):
     r"""Request for UpdateReservation.
+
     Attributes:
         reservation (google.cloud.pubsublite_v1.types.Reservation):
             Required. The reservation to update. Its ``name`` field must
@@ -496,14 +680,21 @@ class UpdateReservationRequest(proto.Message):
             fields to change.
     """
 
-    reservation = proto.Field(proto.MESSAGE, number=1, message=common.Reservation,)
+    reservation = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=common.Reservation,
+    )
     update_mask = proto.Field(
-        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+        proto.MESSAGE,
+        number=2,
+        message=field_mask_pb2.FieldMask,
     )
 
 
 class DeleteReservationRequest(proto.Message):
     r"""Request for DeleteReservation.
+
     Attributes:
         name (str):
             Required. The name of the reservation to delete. Structured
@@ -511,11 +702,15 @@ class DeleteReservationRequest(proto.Message):
             projects/{project_number}/locations/{location}/reservations/{reservation_id}
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ListReservationTopicsRequest(proto.Message):
     r"""Request for ListReservationTopics.
+
     Attributes:
         name (str):
             Required. The name of the reservation whose topics to list.
@@ -536,13 +731,23 @@ class ListReservationTopicsRequest(proto.Message):
             the page token.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class ListReservationTopicsResponse(proto.Message):
     r"""Response for ListReservationTopics.
+
     Attributes:
         topics (Sequence[str]):
             The names of topics attached to the
@@ -558,8 +763,14 @@ class ListReservationTopicsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    topics = proto.RepeatedField(proto.STRING, number=1,)
-    next_page_token = proto.Field(proto.STRING, number=2,)
+    topics = proto.RepeatedField(
+        proto.STRING,
+        number=1,
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
